aboutsummaryrefslogtreecommitdiffstats
path: root/ui/gtk
diff options
context:
space:
mode:
authorBill Meier <wmeier@newsguy.com>2013-12-23 15:53:13 +0000
committerBill Meier <wmeier@newsguy.com>2013-12-23 15:53:13 +0000
commit8ab9c55618a99417b4972f37ab3ee7da58cca0cf (patch)
tree24e3464ee075e7289b2ad4a7e554b251e6355e0b /ui/gtk
parenteecbfd1f3bf613704c043f79543eb5133a046f1d (diff)
From Ville Skyttä: Spelling Fixes
https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=9591 svn path=/trunk/; revision=54387
Diffstat (limited to 'ui/gtk')
-rw-r--r--ui/gtk/compare_stat.c6
-rw-r--r--ui/gtk/dcerpc_stat.c2
-rw-r--r--ui/gtk/iax2_analysis.c2
-rw-r--r--ui/gtk/packet_win.c2
-rw-r--r--ui/gtk/prefs_capture.c4
-rw-r--r--ui/gtk/rtp_analysis.c2
-rw-r--r--ui/gtk/rtp_player.c2
-rw-r--r--ui/gtk/stats_tree_stat.c2
-rw-r--r--ui/gtk/voip_calls.c2
9 files changed, 12 insertions, 12 deletions
diff --git a/ui/gtk/compare_stat.c b/ui/gtk/compare_stat.c
index 3687e66917..c245ee0b10 100644
--- a/ui/gtk/compare_stat.c
+++ b/ui/gtk/compare_stat.c
@@ -83,7 +83,7 @@
#include "ui/gtk/old-gtk-compat.h"
-/* From colorize convertion */
+/* From colorize conversion */
#define COLOR_N 1
/* For checksum */
@@ -272,7 +272,7 @@ call_foreach_count_ip_id(gpointer value, gpointer arg)
/* Detect ongoing package hits, special behavior if start is set to 0 */
if((cs->last_hit||(compare_start==0))&&(cs->start_ongoing_hits<compare_start||(compare_start==0))){
if((compare_start==0)&&(cs->start_ongoing_hits!=0)){
- /* start from the first packet so allready set */
+ /* start from the first packet so already set */
} else {
cs->start_ongoing_hits++;
/* Take the lower number */
@@ -543,7 +543,7 @@ comparestat_draw(void *arg)
frame_info *fInfo;
guint32 first_file_amount, second_file_amount;
- /* inital steps, clear all data before start*/
+ /* initial steps, clear all data before start*/
cs->zebra_time.secs=0;
cs->zebra_time.nsecs=1;
nstime_set_unset(&cs->current_time);
diff --git a/ui/gtk/dcerpc_stat.c b/ui/gtk/dcerpc_stat.c
index c4c04af07f..5a3e384dba 100644
--- a/ui/gtk/dcerpc_stat.c
+++ b/ui/gtk/dcerpc_stat.c
@@ -485,7 +485,7 @@ dcerpcstat_find_next_program(gpointer *key, gpointer *value, gpointer *user_data
/* searching for the next one we are only interested in those
that sorts alphabetically after the current one */
if(strcmp(current_uuid_value->name, v->name) >= 0){
- /* this one doesnt so just skip it */
+ /* this one doesn't so just skip it */
return;
}
diff --git a/ui/gtk/iax2_analysis.c b/ui/gtk/iax2_analysis.c
index 40f0285c48..03f84388a6 100644
--- a/ui/gtk/iax2_analysis.c
+++ b/ui/gtk/iax2_analysis.c
@@ -953,7 +953,7 @@ dialog_graph_draw(user_data_t* user_data)
* so we know how large arrays we need to malloc()
*/
num_time_intervals = user_data->dlg.dialog_graph.num_items;
- /* if there isnt anything to do, just return */
+ /* if there isn't anything to do, just return */
if (num_time_intervals == 0) {
return;
}
diff --git a/ui/gtk/packet_win.c b/ui/gtk/packet_win.c
index 008cc65b42..5e78b9e65b 100644
--- a/ui/gtk/packet_win.c
+++ b/ui/gtk/packet_win.c
@@ -953,7 +953,7 @@ void new_packet_window(GtkWidget *w _U_, gboolean reference, gboolean editable _
return;
}
- /* With the new packetlists "lazy columns" it's neccesary to reread the frame */
+ /* With the new packetlists "lazy columns" it's necessary to reread the frame */
if (!cf_read_frame(&cfile, fd)) {
/* error reading the frame */
return;
diff --git a/ui/gtk/rtp_analysis.c b/ui/gtk/rtp_analysis.c
index 5af2c4eca0..b894fc7565 100644
--- a/ui/gtk/rtp_analysis.c
+++ b/ui/gtk/rtp_analysis.c
@@ -999,7 +999,7 @@ dialog_graph_draw(user_data_t* user_data)
* so we know how large arrays we need to malloc()
*/
num_time_intervals = user_data->dlg.dialog_graph.num_items;
- /* if there isnt anything to do, just return */
+ /* if there isn't anything to do, just return */
if (num_time_intervals == 0) {
return;
}
diff --git a/ui/gtk/rtp_player.c b/ui/gtk/rtp_player.c
index acee55f804..63c9eca427 100644
--- a/ui/gtk/rtp_player.c
+++ b/ui/gtk/rtp_player.c
@@ -2287,7 +2287,7 @@ rtp_player_on_destroy(GObject *object _U_, gpointer user_data _U_)
PaError err;
GtkWidget *dialog;
- /* Stop the channels if necesary */
+ /* Stop the channels if necessary */
if(rtp_channels && (!rtp_channels->stop)){
stop_channels();
}
diff --git a/ui/gtk/stats_tree_stat.c b/ui/gtk/stats_tree_stat.c
index 1b5d610288..2cb38895f8 100644
--- a/ui/gtk/stats_tree_stat.c
+++ b/ui/gtk/stats_tree_stat.c
@@ -80,7 +80,7 @@ struct _tree_pres {
/* Define fixed column indexes */
#define NODEPTR_COLUMN 0 /* Always first column */
-#define N_RESERVED_COL 1 /* Number of columns for internal use - added before visable cols */
+#define N_RESERVED_COL 1 /* Number of columns for internal use - added before visible cols */
static void
diff --git a/ui/gtk/voip_calls.c b/ui/gtk/voip_calls.c
index 08489796c2..448bfcec0d 100644
--- a/ui/gtk/voip_calls.c
+++ b/ui/gtk/voip_calls.c
@@ -1558,7 +1558,7 @@ q931_calls_packet(void *ptr _U_, packet_info *pinfo, epan_dissect_t *edt _U_, co
}
/* check if there is an LRQ/LCF that match this Setup */
- /* TODO: we are just checking the DialedNumer in LRQ/LCF agains the Setup
+ /* TODO: we are just checking the DialedNumer in LRQ/LCF against the Setup
we should also check if the h225 signaling IP and port match the destination
Setup ip and port */
list = g_list_first(tapinfo->callsinfo_list);
diff --git a/ui/gtk/prefs_capture.c b/ui/gtk/prefs_capture.c
index baabd00ede..9960d40c6b 100644
--- a/ui/gtk/prefs_capture.c
+++ b/ui/gtk/prefs_capture.c
@@ -436,7 +436,7 @@ colopts_edit_cb(GtkWidget *w, gpointer data _U_)
gtk_widget_show(col_link_lb);
row++;
/* create "Promiscous Mode" label and button */
col_pmode_cb = gtk_check_button_new();
ws_gtk_grid_attach_defaults(GTK_GRID(main_grid), col_pmode_cb, 0, row, 1, 1);
if (!prefs.capture_columns || prefs_capture_options_dialog_column_is_visible("PMODE"))
@@ -445,7 +445,7 @@ colopts_edit_cb(GtkWidget *w, gpointer data _U_)
gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(col_pmode_cb), FALSE);
gtk_widget_show(col_pmode_cb);
- col_pmode_lb = gtk_label_new("Promiscous Mode");
+ col_pmode_lb = gtk_label_new("Promiscuous Mode");
ws_gtk_grid_attach_defaults(GTK_GRID(main_grid), col_pmode_lb, 1, row, 1, 1);
gtk_misc_set_alignment(GTK_MISC(col_pmode_lb), 0, 0.5f);
gtk_widget_show(col_pmode_lb);
@@ -436,7 +436,7 @@ colopts_edit_cb(GtkWidget *w, gpointer data _U_)
gtk_widget_show(col_link_lb);
row++;
- /* create "Promiscous Mode" label and button */
+ /* create "Promiscuous Mode" label and button */
col_pmode_cb = gtk_check_button_new();
ws_gtk_grid_attach_defaults(GTK_GRID(main_grid), col_pmode_cb, 0, row, 1, 1);